@@ -2,6 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
+
 from . import sale
 
 __all__ = ['register']
@@ -13,3 +14,8 @@ def register():
         sale.Line,
         sale.LineTax,
         module='sale_history', type_='model')
+    Pool.register(
+        sale.Subscription,
+        sale.SubscriptionLine,
+        module='sale_history', type_='model',
+        depends=['sale_subscription'])
